@@ -6,12 +6,11 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"os/exec"
 	"strconv"
 	"strings"
 
-	"github.com/bmf-san/ggc/v7/git"
 	"github.com/bmf-san/ggc/v7/internal/prompt"
+	"github.com/bmf-san/ggc/v7/pkg/git"
 )
 
 // Brancher provides functionality for the branch command.
@@ -50,12 +49,12 @@ func (b *Brancher) handleBranchCommand(cmd string, args []string) {
 	branchCommands := map[string]func([]string){
 		"current":  func([]string) { b.handleCurrentBranch() },
 		"checkout": b.handleCheckoutCommand,
-		"create":   func([]string) { b.branchCreate() },
+		"create":   b.branchCreate,
 		"delete":   b.handleDeleteCommand,
 		"rename":   func([]string) { b.branchRename() },
 		"move":     func([]string) { b.branchMove() },
 		"set":      b.handleSetCommand,
-		"info":     func([]string) { b.branchInfo() },
+		"info":     b.branchInfoArgs,
 		"list":     b.handleListCommand,
 		"sort":     func([]string) { b.branchSort() },
 		"contains": func([]string) { b.branchContains() },
@@ -92,7 +91,7 @@ func (b *Brancher) handleDeleteCommand(args []string) {
 	if len(args) > 0 && args[0] == "merged" {
 		b.branchDeleteMerged()
 	} else {
-		b.branchDelete()
+		b.branchDeleteArgs(args)
 	}
 }
 
@@ -157,7 +156,7 @@ func (b *Brancher) branchCheckoutRemote() {
 	}
 	remoteBranch := branches[idx]
 	localBranch, valid := deriveLocalFromRemote(remoteBranch)
-	if !valid || validateBranchName(localBranch) != nil {
+	if !valid || git.ValidateBranchName(localBranch) != nil {
 		_, _ = fmt.Fprintln(b.outputWriter, "Invalid remote branch name.")
 		return
 	}
@@ -214,17 +213,22 @@ func (b *Brancher) readLine(promptText string) (string, bool) {
 	return line, true
 }
 
-func (b *Brancher) branchCreate() {
-	input, ok := b.readLine("Enter new branch name: ")
-	if !ok {
-		return
+func (b *Brancher) branchCreate(args []string) {
+	var branchName string
+	if len(args) > 0 {
+		branchName = strings.TrimSpace(args[0])
+	} else {
+		input, ok := b.readLine("Enter new branch name: ")
+		if !ok {
+			return
+		}
+		branchName = strings.TrimSpace(input)
+		if branchName == "" {
+			_, _ = fmt.Fprintln(b.outputWriter, "Canceled.")
+			return
+		}
 	}
-	branchName := strings.TrimSpace(input)
-	if branchName == "" {
-		_, _ = fmt.Fprintln(b.outputWriter, "Canceled.")
-		return
-	}
-	if err := validateBranchName(branchName); err != nil {
+	if err := git.ValidateBranchName(branchName); err != nil {
 		_, _ = fmt.Fprintf(b.outputWriter, "Error: invalid branch name: %v\n", err)
 		return
 	}
@@ -235,14 +239,50 @@ func (b *Brancher) branchCreate() {
 	}
 }
 
-func (b *Brancher) branchDelete() {
+func (b *Brancher) branchDeleteArgs(args []string) {
+	if len(args) > 0 {
+		b.deleteBranchesFromArgs(args)
+		return
+	}
+
+	branches, ok := b.collectDeletableBranches()
+	if !ok {
+		return
+	}
+
+	if len(branches) == 0 {
+		_, _ = fmt.Fprintln(b.outputWriter, "No local branches found.")
+		return
+	}
+
+	b.runBranchDeleteLoop(branches)
+}
+
+func (b *Brancher) deleteBranchesFromArgs(args []string) {
+	current, _ := b.gitClient.GetCurrentBranch()
+	for _, a := range args {
+		br := strings.TrimSpace(a)
+		if br == "" {
+			continue
+		}
+		if current != "" && br == current {
+			_, _ = fmt.Fprintf(b.outputWriter, "Skipping current branch: %s\n", br)
+			continue
+		}
+		if err := b.gitClient.DeleteBranch(br); err != nil {
+			_, _ = fmt.Fprintf(b.outputWriter, "Error: %v\n", err)
+		}
+	}
+}
+
+func (b *Brancher) collectDeletableBranches() ([]string, bool) {
 	branches, err := b.gitClient.ListLocalBranches()
 	if err != nil {
 		_, _ = fmt.Fprintf(b.outputWriter, "Error: %v\n", err)
-		return
+		return nil, false
 	}
-	// Exclude current branch from deletion candidates to avoid failing UX
-	if curr, err := b.gitClient.GetCurrentBranch(); err == nil {
+
+	if curr, err := b.gitClient.GetCurrentBranch(); err == nil && curr != "" {
 		filtered := make([]string, 0, len(branches))
 		for _, br := range branches {
 			if br != curr {
@@ -251,12 +291,8 @@ func (b *Brancher) branchDelete() {
 		}
 		branches = filtered
 	}
-	if len(branches) == 0 {
-		_, _ = fmt.Fprintln(b.outputWriter, "No local branches found.")
-		return
-	}
 
-	b.runBranchDeleteLoop(branches)
+	return branches, true
 }
 
 // runBranchDeleteLoop runs the interactive branch deletion loop
@@ -456,23 +492,6 @@ func (b *Brancher) parseMergedBranchIndices(input string, branches []string) ([]
 	return selectedBranches, true
 }
 
-// validateBranchName performs basic validation aligned with git ref rules for branch names.
-// It rejects empty names, control characters, disallowed characters/sequences, invalid prefixes/suffixes,
-// double slashes, overly long names, and non-ASCII for safety across platforms.
-func validateBranchName(name string) error {
-	n := strings.TrimSpace(name)
-	if n == "" {
-		return fmt.Errorf("branch name cannot be empty")
-	}
-	// Delegate validation to git to match exact refname rules.
-	// Equivalent to: git check-ref-format --branch <name>
-	cmd := exec.Command("git", "check-ref-format", "--branch", n)
-	if err := cmd.Run(); err != nil {
-		return fmt.Errorf("invalid per git check-ref-format: %w", err)
-	}
-	return nil
-}
-
 func (b *Brancher) branchRename() {
 	branches, err := b.gitClient.ListLocalBranches()
 	if err != nil {
@@ -497,7 +516,7 @@ func (b *Brancher) branchRename() {
 		_, _ = fmt.Fprintln(b.outputWriter, "Canceled.")
 		return
 	}
-	if err := validateBranchName(newName); err != nil {
+	if err := git.ValidateBranchName(newName); err != nil {
 		_, _ = fmt.Fprintf(b.outputWriter, "Error: invalid branch name: %v\n", err)
 		return
 	}
@@ -601,7 +620,19 @@ func (b *Brancher) selectUpstreamBranch() string {
 	return upIn
 }
 
-func (b *Brancher) branchInfo() {
+func (b *Brancher) branchInfoArgs(args []string) {
+	// If a branch name is provided, show info directly (support multiple names)
+	if len(args) > 0 {
+		for _, a := range args {
+			br := strings.TrimSpace(a)
+			if br == "" {
+				continue
+			}
+			b.printBranchInfo(br)
+		}
+		return
+	}
+
 	branches, err := b.gitClient.ListLocalBranches()
 	if err != nil {
 		_, _ = fmt.Fprintf(b.outputWriter, "Error: %v\n", err)
