@@ -6,8 +6,8 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/bmf-san/ggc/v7/git"
 	"github.com/bmf-san/ggc/v7/internal/prompt"
+	"github.com/bmf-san/ggc/v7/pkg/git"
 )
 
 // mockBranchGitClient is a mock implementation focused on branch operations for tests
@@ -19,6 +19,8 @@ type mockBranchGitClient struct {
 	listRemoteBranches     func() ([]string, error)
 	mergedBranches         []string
 	checkoutNewBranchError bool
+	createdBranches        []string
+	deletedBranches        []string
 	ops                    *mockBranchOperations
 }
 
@@ -43,6 +45,7 @@ func (m *mockBranchGitClient) ListRemoteBranches() ([]string, error) {
 
 // Branch Operations methods
 func (m *mockBranchGitClient) CheckoutNewBranch(branchName string) error {
+	m.createdBranches = append(m.createdBranches, branchName)
 	if m.checkoutNewBranchError {
 		return errors.New("exit status 1")
 	}
@@ -56,7 +59,10 @@ func (m *mockBranchGitClient) CheckoutBranch(_ string) error { return nil }
 func (m *mockBranchGitClient) CheckoutNewBranchFromRemote(_, _ string) error {
 	return nil
 }
-func (m *mockBranchGitClient) DeleteBranch(_ string) error { return nil }
+func (m *mockBranchGitClient) DeleteBranch(name string) error {
+	m.deletedBranches = append(m.deletedBranches, name)
+	return nil
+}
 func (m *mockBranchGitClient) ListMergedBranches() ([]string, error) {
 	if m.mergedBranches != nil {
 		return m.mergedBranches, nil
@@ -318,7 +324,7 @@ func TestBrancher_branchDelete_Success(t *testing.T) {
 		prompter:     prompt.New(strings.NewReader("1 2\n"), &buf),
 	}
 
-	brancher.branchDelete()
+	brancher.branchDeleteArgs(nil)
 
 	output := buf.String()
 	if !strings.Contains(output, "feature/test") {
@@ -342,7 +348,7 @@ func TestBrancher_branchDelete_All(t *testing.T) {
 		prompter:     prompt.New(strings.NewReader("all\n"), &buf),
 	}
 
-	brancher.branchDelete()
+	brancher.branchDeleteArgs(nil)
 
 	output := buf.String()
 	if !strings.Contains(output, "All branches deleted.") {
@@ -363,7 +369,7 @@ func TestBrancher_branchDelete_Cancel(t *testing.T) {
 		prompter:     prompt.New(strings.NewReader("\n"), &buf),
 	}
 
-	brancher.branchDelete()
+	brancher.branchDeleteArgs(nil)
 
 	output := buf.String()
 	if !strings.Contains(output, "Canceled.") {
@@ -383,7 +389,7 @@ func TestBrancher_branchDelete_Error(t *testing.T) {
 		outputWriter: &buf,
 	}
 
-	brancher.branchDelete()
+	brancher.branchDeleteArgs(nil)
 
 	output := buf.String()
 	if !strings.Contains(output, "Error: failed to list branches") {
@@ -403,7 +409,7 @@ func TestBrancher_branchDelete_NoBranches(t *testing.T) {
 		outputWriter: &buf,
 	}
 
-	brancher.branchDelete()
+	brancher.branchDeleteArgs(nil)
 
 	output := buf.String()
 	if !strings.Contains(output, "No local branches found.") {
@@ -651,6 +657,40 @@ func TestBrancher_branchCreate_ExistingBranch(t *testing.T) {
 	}
 }
 
+func TestBrancher_branchCreate_WithArgument(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{}
+	brancher := &Brancher{
+		gitClient:    mockClient,
+		outputWriter: &buf,
+	}
+
+	brancher.Branch([]string{"create", "feature/new"})
+
+	if len(mockClient.createdBranches) != 1 || mockClient.createdBranches[0] != "feature/new" {
+		t.Fatalf("expected branch creation with name %q, got %#v", "feature/new", mockClient.createdBranches)
+	}
+	if output := buf.String(); output != "" {
+		t.Fatalf("expected no output, got %q", output)
+	}
+}
+
+func TestBrancher_branchCreate_WithEmptyArgument(t *testing.T) {
+	var buf bytes.Buffer
+	brancher := &Brancher{
+		gitClient:    &mockBranchGitClient{},
+		outputWriter: &buf,
+	}
+
+	brancher.Branch([]string{"create", "   "})
+
+	output := buf.String()
+	expected := "Error: invalid branch name: branch name cannot be empty\n"
+	if output != expected {
+		t.Errorf("unexpected output for empty argument:\ngot:  %q\nwant: %q", output, expected)
+	}
+}
+
 // Consolidated boundary tests for branch checkout input to avoid repetitive single-case tests.
 // Covers various numeric/non-numeric forms and validates expected outputs for each.
 func TestBrancher_Branch_BoundaryInputValues(t *testing.T) {
@@ -806,7 +846,7 @@ func TestBrancher_Branch_BoundaryBranchNames(t *testing.T) {
 				prompter:     prompt.New(strings.NewReader(tt.branchName+"\n"), &buf),
 			}
 
-			brancher.branchCreate()
+			brancher.branchCreate(nil)
 
 			output := buf.String()
 			if tt.expectedPass {
@@ -884,7 +924,7 @@ func TestBrancher_Branch_BoundaryUserInput(t *testing.T) {
 				prompter:     prompt.New(strings.NewReader(tt.input), &buf),
 			}
 
-			brancher.branchCreate()
+			brancher.branchCreate(nil)
 
 			output := buf.String()
 			if tt.expected != "" {
@@ -1014,7 +1054,7 @@ func TestBrancher_Branch_BoundaryDeleteOperations(t *testing.T) {
 				prompter:     prompt.New(strings.NewReader(tt.input), &buf),
 			}
 
-			brancher.branchDelete()
+			brancher.branchDeleteArgs(nil)
 
 			output := buf.String()
 			if !strings.Contains(output, tt.expected) {
@@ -1065,7 +1105,7 @@ func TestBrancher_Branch_BoundaryRemoteOperations(t *testing.T) {
 				prompter:     prompt.New(strings.NewReader(tt.input), &buf),
 			}
 
-			brancher.branchDelete()
+			brancher.branchDeleteArgs(nil)
 
 			output := buf.String()
 			if !strings.Contains(output, tt.expected) {
@@ -1074,3 +1114,91 @@ func TestBrancher_Branch_BoundaryRemoteOperations(t *testing.T) {
 		})
 	}
 }
+
+func TestBrancher_branchDeleteArgs_WithArgs(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{currentBranch: "main"}
+	brancher := &Brancher{gitClient: mockClient, outputWriter: &buf}
+
+	brancher.branchDeleteArgs([]string{"feature/test"})
+
+	if len(mockClient.deletedBranches) != 1 || mockClient.deletedBranches[0] != "feature/test" {
+		t.Fatalf("expected to delete feature/test, got %v", mockClient.deletedBranches)
+	}
+	if got := buf.String(); got != "" {
+		t.Errorf("expected no output on successful deletion, got %q", got)
+	}
+}
+
+func TestBrancher_branchDeleteArgs_MultipleAndSkipCurrent(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{currentBranch: "main"}
+	brancher := &Brancher{gitClient: mockClient, outputWriter: &buf}
+
+	brancher.branchDeleteArgs([]string{"main", "feature/test", "foo"})
+
+	// Should skip current branch 'main'
+	if got := buf.String(); !strings.Contains(got, "Skipping current branch: main") {
+		t.Errorf("expected skip message, got %q", got)
+	}
+	if len(mockClient.deletedBranches) != 2 {
+		t.Fatalf("expected 2 deletions, got %d (%v)", len(mockClient.deletedBranches), mockClient.deletedBranches)
+	}
+	if mockClient.deletedBranches[0] != "feature/test" || mockClient.deletedBranches[1] != "foo" {
+		t.Errorf("unexpected deleted branches: %v", mockClient.deletedBranches)
+	}
+}
+
+func TestBrancher_branchDeleteArgs_NoArgsFallsBackInteractive(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{}
+	brancher := &Brancher{gitClient: mockClient, outputWriter: &buf, prompter: prompt.New(strings.NewReader("1\n"), &buf)}
+
+	brancher.branchDeleteArgs(nil)
+
+	if got := buf.String(); !strings.Contains(got, "Selected branches deleted.") {
+		t.Errorf("expected interactive deletion confirmation, got %q", got)
+	}
+	if len(mockClient.deletedBranches) == 0 {
+		t.Error("expected at least one branch deletion call")
+	}
+}
+
+func TestBrancher_branchInfoArgs_WithArgs(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{currentBranch: "main"}
+	brancher := &Brancher{gitClient: mockClient, outputWriter: &buf}
+
+	brancher.branchInfoArgs([]string{"feature/test"})
+
+	out := buf.String()
+	if !strings.Contains(out, "Name: feature/test") {
+		t.Errorf("expected branch info to be printed; got %q", out)
+	}
+}
+
+func TestBrancher_branchInfoArgs_Multiple(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{}
+	brancher := &Brancher{gitClient: mockClient, outputWriter: &buf}
+
+	brancher.branchInfoArgs([]string{"main", "feature/test"})
+
+	out := buf.String()
+	if !strings.Contains(out, "Name: main") || !strings.Contains(out, "Name: feature/test") {
+		t.Errorf("expected info for both branches; got %q", out)
+	}
+}
+
+func TestBrancher_branchInfoArgs_NoArgsFallsBackInteractive(t *testing.T) {
+	var buf bytes.Buffer
+	mockClient := &mockBranchGitClient{}
+	brancher := &Brancher{gitClient: mockClient, outputWriter: &buf, prompter: prompt.New(strings.NewReader("2\n"), &buf)}
+
+	brancher.branchInfoArgs(nil)
+
+	out := buf.String()
+	if !strings.Contains(out, "Name: feature/test") {
+		t.Errorf("expected info printed for selected branch; got %q", out)
+	}
+}
