@@ -11,16 +11,17 @@ import (
 	"syscall"
 
 	commandregistry "github.com/bmf-san/ggc/v7/cmd/command"
-	"github.com/bmf-san/ggc/v7/git"
+	"github.com/bmf-san/ggc/v7/internal/interactive"
+	"github.com/bmf-san/ggc/v7/pkg/git"
 )
 
 // Interactive mode special return values
 // These constants are used to signal special states when returning from interactive mode
 const (
 	// InteractiveQuitCommand signals that the user wants to quit the interactive mode
-	InteractiveQuitCommand = "quit"
+	InteractiveQuitCommand = interactive.InteractiveQuitCommand
 	// InteractiveWorkflowCommand signals that a workflow has been executed and the interactive mode should restart
-	InteractiveWorkflowCommand = "workflow-executed"
+	InteractiveWorkflowCommand = interactive.InteractiveWorkflowCommand
 )
 
 // Executer is an interface for executing commands.
@@ -248,20 +249,19 @@ func (c *Cmd) DebugKeys(args []string) {
 
 // Interactive starts the interactive UI mode.
 func (c *Cmd) Interactive() {
-	// Reset existing signal handlers
-	signal.Reset(os.Interrupt, syscall.SIGTERM)
-
-	// Set up global Ctrl+C handling
+	// Set up global Ctrl+C handling without introducing a reset window
 	sigChan := make(chan os.Signal, 1)
 	signal.Notify(sigChan, os.Interrupt, syscall.SIGTERM)
+	defer signal.Stop(sigChan)
 	go func() {
 		<-sigChan
 		fmt.Println("\nExiting...")
+		signal.Stop(sigChan)
 		os.Exit(0)
 	}()
 
 	// Create persistent UI instance to preserve state
-	ui := NewUI(c.gitClient, c)
+	ui := interactive.NewUI(c.gitClient, c)
 
 	for {
 		args := ui.Run()
@@ -278,6 +278,7 @@ func (c *Cmd) Interactive() {
 		if len(args) >= 2 && args[1] == InteractiveWorkflowCommand {
 			// Workflow was executed, wait for user to continue
 			c.waitForContinue()
+			ui.ResetToSearchMode()
 			continue
 		}
 
@@ -285,6 +286,7 @@ func (c *Cmd) Interactive() {
 
 		// Wait for user to continue
 		c.waitForContinue()
+		ui.ResetToSearchMode()
 	}
 }
 
